@@ -15,7 +15,6 @@ import 'gmp/commands/filters';
 import 'gmp/commands/groups';
 import 'gmp/commands/hosts';
 import 'gmp/commands/license';
-import 'gmp/commands/resource-names';
 import 'gmp/commands/notes';
 import 'gmp/commands/nvt';
 import 'gmp/commands/nvt-families';
@@ -27,7 +26,6 @@ import 'gmp/commands/report-formats';
 import 'gmp/commands/results';
 import 'gmp/commands/scan-configs';
 import 'gmp/commands/schedules';
-import 'gmp/commands/tags';
 import 'gmp/commands/tickets';
 import 'gmp/commands/tls-certificates';
 import 'gmp/commands/vulns';
@@ -55,10 +53,13 @@ import PermissionsCommand from 'gmp/commands/permissions';
 import {PortListCommand, PortListsCommand} from 'gmp/commands/port-lists';
 import ReportCommand from 'gmp/commands/report';
 import ReportsCommand from 'gmp/commands/reports';
+import ResourceNamesCommand from 'gmp/commands/resource-names';
 import RoleCommand from 'gmp/commands/role';
 import RolesCommand from 'gmp/commands/roles';
 import ScannerCommand from 'gmp/commands/scanner';
 import ScannersCommand from 'gmp/commands/scanners';
+import TagCommand from 'gmp/commands/tag';
+import TagsCommand from 'gmp/commands/tags';
 import TargetCommand from 'gmp/commands/target';
 import TargetsCommand from 'gmp/commands/targets';
 import TaskCommand from 'gmp/commands/task';
@@ -109,10 +110,13 @@ class Gmp {
   readonly portlists: PortListsCommand;
   readonly report: ReportCommand;
   readonly reports: ReportsCommand;
+  readonly resourcenames: ResourceNamesCommand;
   readonly role: RoleCommand;
   readonly roles: RolesCommand;
   readonly scanner: ScannerCommand;
   readonly scanners: ScannersCommand;
+  readonly tag: TagCommand;
+  readonly tags: TagsCommand;
   readonly target: TargetCommand;
   readonly targets: TargetsCommand;
   readonly task: TaskCommand;
@@ -159,10 +163,13 @@ class Gmp {
     this.portlists = new PortListsCommand(this.http);
     this.report = new ReportCommand(this.http);
     this.reports = new ReportsCommand(this.http);
+    this.resourcenames = new ResourceNamesCommand(this.http);
     this.role = new RoleCommand(this.http);
     this.roles = new RolesCommand(this.http);
     this.scanner = new ScannerCommand(this.http);
     this.scanners = new ScannersCommand(this.http);
+    this.tag = new TagCommand(this.http);
+    this.tags = new TagsCommand(this.http);
     this.target = new TargetCommand(this.http);
     this.targets = new TargetsCommand(this.http);
     this.task = new TaskCommand(this.http);
