@@ -7,8 +7,10 @@ import {useMemo} from 'react';
 import timezones, {DEFAULT_TIMEZONE} from 'gmp/time-zones';
 import Select, {type SelectProps} from 'web/components/form/Select';
 
-interface TimeZoneSelectProps
-  extends Omit<SelectProps<string>, 'items' | 'value'> {
+interface TimeZoneSelectProps extends Omit<
+  SelectProps<string>,
+  'items' | 'value'
+> {
   value?: string;
 }
 
