@@ -14,7 +14,7 @@ import {
 } from 'web/testing';
 import PortList from 'gmp/models/port-list';
 import Button from 'web/components/form/Button';
-import {currentSettingsDefaultResponse} from 'web/pages/__mocks__/current-settings';
+import {currentSettingsDefaultResponse} from 'web/pages/__fixtures__/current-settings';
 import PortListComponent from 'web/pages/portlists/PortListComponent';
 
 const defaultGetPortListResponse = {
